# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/config/postgresql13_1c.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/postgresql/v1/config/postgresql13_1c.proto',
  package='yandex.cloud.mdb.postgresql.v1.config',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.mdb.postgresql.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1/config;postgresql',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;yandex/cloud/mdb/postgresql/v1/config/postgresql13_1c.proto\x12%yandex.cloud.mdb.postgresql.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xca\x63\n\x15PostgresqlConfig13_1C\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0eshared_buffers\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0ctemp_buffers\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08work_mem\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14maintenance_work_mem\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x61utovacuum_work_mem\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0ftemp_file_limit\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11vacuum_cost_delay\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14vacuum_cost_page_hit\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15vacuum_cost_page_miss\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16vacuum_cost_page_dirty\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11vacuum_cost_limit\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x41\n\x0e\x62gwriter_delay\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-10000\x12:\n\x15\x62gwriter_lru_maxpages\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x17\x62gwriter_lru_multiplier\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x45\n\x14\x62gwriter_flush_after\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-2048\x12\x44\n\x13\x62\x61\x63kend_flush_after\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-2048\x12L\n\x16old_snapshot_threshold\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b-1-86400000\x12X\n\twal_level\x18\x14 \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.WalLevel\x12j\n\x12synchronous_commit\x18\x15 \x01(\x0e\x32N.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.SynchronousCommit\x12K\n\x12\x63heckpoint_timeout\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x33\x30\x30\x30\x30-86400000\x12\x42\n\x1c\x63heckpoint_completion_target\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12G\n\x16\x63heckpoint_flush_after\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-2048\x12\x31\n\x0cmax_wal_size\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cmin_wal_size\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bmax_standby_streaming_delay\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19\x64\x65\x66\x61ult_statistics_target\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12n\n\x14\x63onstraint_exclusion\x18\x1d \x01(\x0e\x32P.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.ConstraintExclusion\x12;\n\x15\x63ursor_tuple_fraction\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n\x13\x66rom_collapse_limit\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x31-2147483647\x12J\n\x13join_collapse_limit\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x31-2147483647\x12k\n\x13\x66orce_parallel_mode\x18! \x01(\x0e\x32N.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.ForceParallelMode\x12\x62\n\x13\x63lient_min_messages\x18\" \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogLevel\x12_\n\x10log_min_messages\x18# \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogLevel\x12\x66\n\x17log_min_error_statement\x18$ \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogLevel\x12?\n\x1alog_min_duration_statement\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0flog_checkpoints\x18& \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0flog_connections\x18\' \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18( \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_duration\x18) \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12k\n\x13log_error_verbosity\x18* \x01(\x0e\x32N.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogErrorVerbosity\x12\x32\n\x0elog_lock_waits\x18+ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\rlog_statement\x18, \x01(\x0e\x32I.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogStatement\x12\x33\n\x0elog_temp_files\x18- \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x13\n\x0bsearch_path\x18. \x01(\t\x12\x30\n\x0crow_security\x18/ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12x\n\x1d\x64\x65\x66\x61ult_transaction_isolation\x18\x30 \x01(\x0e\x32Q.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.TransactionIsolation\x12\x36\n\x11statement_timeout\x18\x31 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0clock_timeout\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12H\n#idle_in_transaction_session_timeout\x18\x33 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12^\n\x0c\x62ytea_output\x18\x34 \x01(\x0e\x32H.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.ByteaOutput\x12Y\n\txmlbinary\x18\x35 \x01(\x0e\x32\x46.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.XmlBinary\x12Y\n\txmloption\x18\x36 \x01(\x0e\x32\x46.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.XmlOption\x12;\n\x16gin_pending_list_limit\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10\x64\x65\x61\x64lock_timeout\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_locks_per_transaction\x18\x39 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_pred_locks_per_transaction\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0b\x61rray_nulls\x18; \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x64\n\x0f\x62\x61\x63kslash_quote\x18< \x01(\x0e\x32K.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.BackslashQuote\x12\x35\n\x11\x64\x65\x66\x61ult_with_oids\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15\x65scape_string_warning\x18> \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14lo_compat_privileges\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x1boperator_precedence_warning\x18@ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15quote_all_identifiers\x18\x41 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x1bstandard_conforming_strings\x18\x42 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14synchronize_seqscans\x18\x43 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15transform_null_equals\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rexit_on_error\x18\x45 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\rseq_page_cost\x18\x46 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10random_page_cost\x18G \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x45\n\x16\x61utovacuum_max_workers\x18H \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-32\x12M\n\x1c\x61utovacuum_vacuum_cost_delay\x18I \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06-1-100\x12O\n\x1c\x61utovacuum_vacuum_cost_limit\x18J \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08-1-10000\x12J\n\x12\x61utovacuum_naptime\x18K \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r1000-86400000\x12H\n\x0f\x61rchive_timeout\x18L \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x30\x30\x30-86400000\x12N\n\x19track_activity_query_size\x18M \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n100-102400\x12\x39\n\x15online_analyze_enable\x18O \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x65nable_bitmapscan\x18P \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_hashagg\x18Q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_hashjoin\x18R \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x65nable_indexscan\x18S \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65nable_indexonlyscan\x18T \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_material\x18U \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x65nable_mergejoin\x18V \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_nestloop\x18W \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_seqscan\x18X \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x65nable_sort\x18Y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_tidscan\x18Z \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n\x14max_worker_processes\x18[ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12\x45\n\x14max_parallel_workers\x18\\ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12P\n\x1fmax_parallel_workers_per_gather\x18] \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12Q\n\x1e\x61utovacuum_vacuum_scale_factor\x18^ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12R\n\x1f\x61utovacuum_analyze_scale_factor\x18_ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12\x41\n\x1d\x64\x65\x66\x61ult_transaction_read_only\x18` \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x10\n\x08timezone\x18\x61 \x01(\t\x12:\n\x16\x65nable_parallel_append\x18\x62 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65nable_parallel_hash\x18\x63 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x18\x65nable_partition_pruning\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1e\x65nable_partitionwise_aggregate\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x19\x65nable_partitionwise_join\x18\x66 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\x03jit\x18g \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n max_parallel_maintenance_workers\x18h \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x1dparallel_leader_participation\x18i \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12^\n!vacuum_cleanup_index_scale_factor\x18j \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x15\xfa\xc7\x31\x11\x30.0-10000000000.0\x12N\n\x1blog_transaction_sample_rate\x18k \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12\x63\n\x0fplan_cache_mode\x18l \x01(\x0e\x32J.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.PlanCacheMode\x12I\n\x18\x65\x66\x66\x65\x63tive_io_concurrency\x18m \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1000\x12M\n\x14\x65\x66\x66\x65\x63tive_cache_size\x18n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-549755813888\x12u\n\x18shared_preload_libraries\x18o \x03(\x0e\x32S.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.SharedPreloadLibraries\x12U\n\x1d\x61uto_explain_log_min_duration\x18p \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12<\n\x18\x61uto_explain_log_analyze\x18q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x18\x61uto_explain_log_buffers\x18r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x17\x61uto_explain_log_timing\x18s \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x19\x61uto_explain_log_triggers\x18t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x18\x61uto_explain_log_verbose\x18u \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\"auto_explain_log_nested_statements\x18v \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\x18\x61uto_explain_sample_rate\x18w \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12<\n\x18pg_hint_plan_enable_hint\x18x \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1epg_hint_plan_enable_hint_table\x18y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12s\n\x18pg_hint_plan_debug_print\x18z \x01(\x0e\x32Q.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.PgHintPlanDebugPrint\x12i\n\x1apg_hint_plan_message_level\x18{ \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogLevel\x12I\n\x13hash_mem_multiplier\x18| \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\xc7\x31\n0.0-1000.0\x12W\n\x19logical_decoding_work_mem\x18~ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x17\xfa\xc7\x31\x13\x36\x35\x35\x33\x36-1099511627776\x12K\n\x1amaintenance_io_concurrency\x18\x7f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1000\x12U\n\x16max_slot_wal_keep_size\x18\x80\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x17\xfa\xc7\x31\x13-1-2251799812636672\x12L\n\rwal_keep_size\x18\x81\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x17\xfa\xc7\x31\x13-1-2251799812636672\x12<\n\x17\x65nable_incremental_sort\x18\x82\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12[\n\"autovacuum_vacuum_insert_threshold\x18\x83\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12[\n%autovacuum_vacuum_insert_scale_factor\x18\x84\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\r\xfa\xc7\x31\t0.0-100.0\x12P\n\x17log_min_duration_sample\x18\x85\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12M\n\x19log_statement_sample_rate\x18\x86\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12Q\n\x18log_parameter_max_length\x18\x87\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12Z\n!log_parameter_max_length_on_error\x18\x88\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12\x39\n\x14pg_qualstats_enabled\x18\x89\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1cpg_qualstats_track_constants\x18\x8a\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x10pg_qualstats_max\x18\x8b\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19pg_qualstats_resolve_oids\x18\x8c\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x18pg_qualstats_sample_rate\x18\x8d\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\x19plantuner_fix_empty_table\x18\x95\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x04geqo\x18\x98\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\x0egeqo_threshold\x18\x99\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x32-2147483647\x12;\n\x0bgeqo_effort\x18\x9a\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-10\x12\x34\n\x0egeqo_pool_size\x18\x9b\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10geqo_generations\x18\x9c\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n\x13geqo_selection_bias\x18\x9d\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x31.5-2.0\x12=\n\tgeqo_seed\x18\x9e\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\"\x9a\x01\n\x0e\x42\x61\x63kslashQuote\x12\x1f\n\x1b\x42\x41\x43KSLASH_QUOTE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41\x43KSLASH_QUOTE\x10\x01\x12\x16\n\x12\x42\x41\x43KSLASH_QUOTE_ON\x10\x02\x12\x17\n\x13\x42\x41\x43KSLASH_QUOTE_OFF\x10\x03\x12!\n\x1d\x42\x41\x43KSLASH_QUOTE_SAFE_ENCODING\x10\x04\"[\n\x0b\x42yteaOutput\x12\x1c\n\x18\x42YTEA_OUTPUT_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42YTEA_OUTPUT_HEX\x10\x01\x12\x18\n\x14\x42YTEA_OUTPUT_ESCAPED\x10\x02\"\x9a\x01\n\x13\x43onstraintExclusion\x12$\n CONSTRAINT_EXCLUSION_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONSTRAINT_EXCLUSION_ON\x10\x01\x12\x1c\n\x18\x43ONSTRAINT_EXCLUSION_OFF\x10\x02\x12\"\n\x1e\x43ONSTRAINT_EXCLUSION_PARTITION\x10\x03\"\x92\x01\n\x11\x46orceParallelMode\x12#\n\x1f\x46ORCE_PARALLEL_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x46ORCE_PARALLEL_MODE_ON\x10\x01\x12\x1b\n\x17\x46ORCE_PARALLEL_MODE_OFF\x10\x02\x12\x1f\n\x1b\x46ORCE_PARALLEL_MODE_REGRESS\x10\x03\"\x99\x01\n\x11LogErrorVerbosity\x12#\n\x1fLOG_ERROR_VERBOSITY_UNSPECIFIED\x10\x00\x12\x1d\n\x19LOG_ERROR_VERBOSITY_TERSE\x10\x01\x12\x1f\n\x1bLOG_ERROR_VERBOSITY_DEFAULT\x10\x02\x12\x1f\n\x1bLOG_ERROR_VERBOSITY_VERBOSE\x10\x03\"\x92\x02\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\x14\n\x10LOG_LEVEL_DEBUG5\x10\x01\x12\x14\n\x10LOG_LEVEL_DEBUG4\x10\x02\x12\x14\n\x10LOG_LEVEL_DEBUG3\x10\x03\x12\x14\n\x10LOG_LEVEL_DEBUG2\x10\x04\x12\x14\n\x10LOG_LEVEL_DEBUG1\x10\x05\x12\x11\n\rLOG_LEVEL_LOG\x10\x06\x12\x14\n\x10LOG_LEVEL_NOTICE\x10\x07\x12\x15\n\x11LOG_LEVEL_WARNING\x10\x08\x12\x13\n\x0fLOG_LEVEL_ERROR\x10\t\x12\x13\n\x0fLOG_LEVEL_FATAL\x10\n\x12\x13\n\x0fLOG_LEVEL_PANIC\x10\x0b\"\x8a\x01\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x16\n\x12LOG_STATEMENT_NONE\x10\x01\x12\x15\n\x11LOG_STATEMENT_DDL\x10\x02\x12\x15\n\x11LOG_STATEMENT_MOD\x10\x03\x12\x15\n\x11LOG_STATEMENT_ALL\x10\x04\"\xd0\x01\n\x14PgHintPlanDebugPrint\x12(\n$PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED\x10\x00\x12 \n\x1cPG_HINT_PLAN_DEBUG_PRINT_OFF\x10\x01\x12\x1f\n\x1bPG_HINT_PLAN_DEBUG_PRINT_ON\x10\x02\x12%\n!PG_HINT_PLAN_DEBUG_PRINT_DETAILED\x10\x03\x12$\n PG_HINT_PLAN_DEBUG_PRINT_VERBOSE\x10\x04\"\x99\x01\n\rPlanCacheMode\x12\x1f\n\x1bPLAN_CACHE_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14PLAN_CACHE_MODE_AUTO\x10\x01\x12%\n!PLAN_CACHE_MODE_FORCE_CUSTOM_PLAN\x10\x02\x12&\n\"PLAN_CACHE_MODE_FORCE_GENERIC_PLAN\x10\x03\"\x8a\x03\n\x16SharedPreloadLibraries\x12(\n$SHARED_PRELOAD_LIBRARIES_UNSPECIFIED\x10\x00\x12)\n%SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN\x10\x01\x12)\n%SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN\x10\x02\x12(\n$SHARED_PRELOAD_LIBRARIES_TIMESCALEDB\x10\x03\x12)\n%SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS\x10\x04\x12$\n SHARED_PRELOAD_LIBRARIES_PG_CRON\x10\x05\x12&\n\"SHARED_PRELOAD_LIBRARIES_PGLOGICAL\x10\x06\x12\'\n#SHARED_PRELOAD_LIBRARIES_PG_PREWARM\x10\x07\x12$\n SHARED_PRELOAD_LIBRARIES_PGAUDIT\x10\x08\"\xd6\x01\n\x11SynchronousCommit\x12\"\n\x1eSYNCHRONOUS_COMMIT_UNSPECIFIED\x10\x00\x12\x19\n\x15SYNCHRONOUS_COMMIT_ON\x10\x01\x12\x1a\n\x16SYNCHRONOUS_COMMIT_OFF\x10\x02\x12\x1c\n\x18SYNCHRONOUS_COMMIT_LOCAL\x10\x03\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_WRITE\x10\x04\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_APPLY\x10\x05\"\xe6\x01\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12*\n&TRANSACTION_ISOLATION_READ_UNCOMMITTED\x10\x01\x12(\n$TRANSACTION_ISOLATION_READ_COMMITTED\x10\x02\x12)\n%TRANSACTION_ISOLATION_REPEATABLE_READ\x10\x03\x12&\n\"TRANSACTION_ISOLATION_SERIALIZABLE\x10\x04\"S\n\x08WalLevel\x12\x19\n\x15WAL_LEVEL_UNSPECIFIED\x10\x00\x12\x15\n\x11WAL_LEVEL_REPLICA\x10\x01\x12\x15\n\x11WAL_LEVEL_LOGICAL\x10\x02\"R\n\tXmlBinary\x12\x1a\n\x16XML_BINARY_UNSPECIFIED\x10\x00\x12\x15\n\x11XML_BINARY_BASE64\x10\x01\x12\x12\n\x0eXML_BINARY_HEX\x10\x02\"X\n\tXmlOption\x12\x1a\n\x16XML_OPTION_UNSPECIFIED\x10\x00\x12\x17\n\x13XML_OPTION_DOCUMENT\x10\x01\x12\x16\n\x12XML_OPTION_CONTENT\x10\x02\"\x9b\x02\n\x18PostgresqlConfigSet13_1C\x12V\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C\x12Q\n\x0buser_config\x18\x02 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C\x12T\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1CB\x81\x01\n)yandex.cloud.api.mdb.postgresql.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1/config;postgresqlb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_POSTGRESQLCONFIG13_1C_BACKSLASHQUOTE = _descriptor.EnumDescriptor(
  name='BackslashQuote',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.BackslashQuote',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BACKSLASH_QUOTE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKSLASH_QUOTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKSLASH_QUOTE_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKSLASH_QUOTE_OFF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKSLASH_QUOTE_SAFE_ENCODING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10312,
  serialized_end=10466,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_BACKSLASHQUOTE)

_POSTGRESQLCONFIG13_1C_BYTEAOUTPUT = _descriptor.EnumDescriptor(
  name='ByteaOutput',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.ByteaOutput',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BYTEA_OUTPUT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BYTEA_OUTPUT_HEX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BYTEA_OUTPUT_ESCAPED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10468,
  serialized_end=10559,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_BYTEAOUTPUT)

_POSTGRESQLCONFIG13_1C_CONSTRAINTEXCLUSION = _descriptor.EnumDescriptor(
  name='ConstraintExclusion',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.ConstraintExclusion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSTRAINT_EXCLUSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSTRAINT_EXCLUSION_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSTRAINT_EXCLUSION_OFF', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSTRAINT_EXCLUSION_PARTITION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10562,
  serialized_end=10716,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_CONSTRAINTEXCLUSION)

_POSTGRESQLCONFIG13_1C_FORCEPARALLELMODE = _descriptor.EnumDescriptor(
  name='ForceParallelMode',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.ForceParallelMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORCE_PARALLEL_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORCE_PARALLEL_MODE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORCE_PARALLEL_MODE_OFF', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORCE_PARALLEL_MODE_REGRESS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10719,
  serialized_end=10865,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_FORCEPARALLELMODE)

_POSTGRESQLCONFIG13_1C_LOGERRORVERBOSITY = _descriptor.EnumDescriptor(
  name='LogErrorVerbosity',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogErrorVerbosity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_ERROR_VERBOSITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_ERROR_VERBOSITY_TERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_ERROR_VERBOSITY_DEFAULT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_ERROR_VERBOSITY_VERBOSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10868,
  serialized_end=11021,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_LOGERRORVERBOSITY)

_POSTGRESQLCONFIG13_1C_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_DEBUG5', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_DEBUG4', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_DEBUG3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_DEBUG2', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_DEBUG1', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_LOG', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_NOTICE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_WARNING', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_FATAL', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_PANIC', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11024,
  serialized_end=11298,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_LOGLEVEL)

_POSTGRESQLCONFIG13_1C_LOGSTATEMENT = _descriptor.EnumDescriptor(
  name='LogStatement',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.LogStatement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_STATEMENT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_STATEMENT_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_STATEMENT_DDL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_STATEMENT_MOD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_STATEMENT_ALL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11301,
  serialized_end=11439,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_LOGSTATEMENT)

_POSTGRESQLCONFIG13_1C_PGHINTPLANDEBUGPRINT = _descriptor.EnumDescriptor(
  name='PgHintPlanDebugPrint',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.PgHintPlanDebugPrint',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PG_HINT_PLAN_DEBUG_PRINT_OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PG_HINT_PLAN_DEBUG_PRINT_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PG_HINT_PLAN_DEBUG_PRINT_DETAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PG_HINT_PLAN_DEBUG_PRINT_VERBOSE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11442,
  serialized_end=11650,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_PGHINTPLANDEBUGPRINT)

_POSTGRESQLCONFIG13_1C_PLANCACHEMODE = _descriptor.EnumDescriptor(
  name='PlanCacheMode',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.PlanCacheMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLAN_CACHE_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAN_CACHE_MODE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAN_CACHE_MODE_FORCE_CUSTOM_PLAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAN_CACHE_MODE_FORCE_GENERIC_PLAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11653,
  serialized_end=11806,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_PLANCACHEMODE)

_POSTGRESQLCONFIG13_1C_SHAREDPRELOADLIBRARIES = _descriptor.EnumDescriptor(
  name='SharedPreloadLibraries',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.SharedPreloadLibraries',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_TIMESCALEDB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_PG_CRON', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_PGLOGICAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_PG_PREWARM', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_PRELOAD_LIBRARIES_PGAUDIT', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11809,
  serialized_end=12203,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_SHAREDPRELOADLIBRARIES)

_POSTGRESQLCONFIG13_1C_SYNCHRONOUSCOMMIT = _descriptor.EnumDescriptor(
  name='SynchronousCommit',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.SynchronousCommit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS_COMMIT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS_COMMIT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS_COMMIT_OFF', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS_COMMIT_LOCAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS_COMMIT_REMOTE_WRITE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS_COMMIT_REMOTE_APPLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12206,
  serialized_end=12420,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_SYNCHRONOUSCOMMIT)

_POSTGRESQLCONFIG13_1C_TRANSACTIONISOLATION = _descriptor.EnumDescriptor(
  name='TransactionIsolation',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.TransactionIsolation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ISOLATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ISOLATION_READ_UNCOMMITTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ISOLATION_READ_COMMITTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ISOLATION_REPEATABLE_READ', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ISOLATION_SERIALIZABLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12423,
  serialized_end=12653,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_TRANSACTIONISOLATION)

_POSTGRESQLCONFIG13_1C_WALLEVEL = _descriptor.EnumDescriptor(
  name='WalLevel',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.WalLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WAL_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAL_LEVEL_REPLICA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAL_LEVEL_LOGICAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12655,
  serialized_end=12738,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_WALLEVEL)

_POSTGRESQLCONFIG13_1C_XMLBINARY = _descriptor.EnumDescriptor(
  name='XmlBinary',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.XmlBinary',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='XML_BINARY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XML_BINARY_BASE64', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XML_BINARY_HEX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12740,
  serialized_end=12822,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_XMLBINARY)

_POSTGRESQLCONFIG13_1C_XMLOPTION = _descriptor.EnumDescriptor(
  name='XmlOption',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.XmlOption',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='XML_OPTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XML_OPTION_DOCUMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XML_OPTION_CONTENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12824,
  serialized_end=12912,
)
_sym_db.RegisterEnumDescriptor(_POSTGRESQLCONFIG13_1C_XMLOPTION)


_POSTGRESQLCONFIG13_1C = _descriptor.Descriptor(
  name='PostgresqlConfig13_1C',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_buffers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.shared_buffers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_buffers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.temp_buffers', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_prepared_transactions', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_prepared_transactions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='work_mem', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.work_mem', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_work_mem', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.maintenance_work_mem', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_work_mem', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_work_mem', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_file_limit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.temp_file_limit', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vacuum_cost_delay', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.vacuum_cost_delay', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vacuum_cost_page_hit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.vacuum_cost_page_hit', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vacuum_cost_page_miss', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.vacuum_cost_page_miss', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vacuum_cost_page_dirty', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.vacuum_cost_page_dirty', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vacuum_cost_limit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.vacuum_cost_limit', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgwriter_delay', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.bgwriter_delay', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgwriter_lru_maxpages', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.bgwriter_lru_maxpages', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgwriter_lru_multiplier', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.bgwriter_lru_multiplier', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgwriter_flush_after', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.bgwriter_flush_after', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-2048', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_flush_after', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.backend_flush_after', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-2048', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_snapshot_threshold', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.old_snapshot_threshold', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\013-1-86400000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wal_level', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.wal_level', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='synchronous_commit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.synchronous_commit', index=20,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_timeout', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.checkpoint_timeout', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01630000-86400000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_completion_target', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.checkpoint_completion_target', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_flush_after', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.checkpoint_flush_after', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-2048', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_wal_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_wal_size', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_wal_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.min_wal_size', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_standby_streaming_delay', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_standby_streaming_delay', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_statistics_target', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.default_statistics_target', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraint_exclusion', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.constraint_exclusion', index=28,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cursor_tuple_fraction', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.cursor_tuple_fraction', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_collapse_limit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.from_collapse_limit', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0141-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_collapse_limit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.join_collapse_limit', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0141-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force_parallel_mode', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.force_parallel_mode', index=32,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_min_messages', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.client_min_messages', index=33,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_min_messages', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_min_messages', index=34,
      number=35, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_min_error_statement', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_min_error_statement', index=35,
      number=36, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_min_duration_statement', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_min_duration_statement', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_checkpoints', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_checkpoints', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_connections', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_connections', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_disconnections', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_disconnections', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_duration', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_duration', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_error_verbosity', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_error_verbosity', index=41,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_lock_waits', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_lock_waits', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_statement', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_statement', index=43,
      number=44, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_temp_files', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_temp_files', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_path', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.search_path', index=45,
      number=46, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='row_security', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.row_security', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_transaction_isolation', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.default_transaction_isolation', index=47,
      number=48, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statement_timeout', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.statement_timeout', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_timeout', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.lock_timeout', index=49,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_in_transaction_session_timeout', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.idle_in_transaction_session_timeout', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytea_output', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.bytea_output', index=51,
      number=52, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xmlbinary', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.xmlbinary', index=52,
      number=53, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xmloption', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.xmloption', index=53,
      number=54, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gin_pending_list_limit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.gin_pending_list_limit', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deadlock_timeout', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.deadlock_timeout', index=55,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_locks_per_transaction', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_locks_per_transaction', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pred_locks_per_transaction', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_pred_locks_per_transaction', index=57,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_nulls', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.array_nulls', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backslash_quote', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.backslash_quote', index=59,
      number=60, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_with_oids', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.default_with_oids', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='escape_string_warning', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.escape_string_warning', index=61,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lo_compat_privileges', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.lo_compat_privileges', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator_precedence_warning', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.operator_precedence_warning', index=63,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_all_identifiers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.quote_all_identifiers', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standard_conforming_strings', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.standard_conforming_strings', index=65,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='synchronize_seqscans', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.synchronize_seqscans', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform_null_equals', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.transform_null_equals', index=67,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_on_error', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.exit_on_error', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq_page_cost', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.seq_page_cost', index=69,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_page_cost', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.random_page_cost', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_max_workers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_max_workers', index=71,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0041-32', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_vacuum_cost_delay', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_vacuum_cost_delay', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006-1-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_vacuum_cost_limit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_vacuum_cost_limit', index=73,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\010-1-10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_naptime', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_naptime', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r1000-86400000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archive_timeout', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.archive_timeout', index=75,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01610000-86400000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_activity_query_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.track_activity_query_size', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\n100-102400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_analyze_enable', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.online_analyze_enable', index=77,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_bitmapscan', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_bitmapscan', index=78,
      number=80, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hashagg', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_hashagg', index=79,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hashjoin', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_hashjoin', index=80,
      number=82, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_indexscan', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_indexscan', index=81,
      number=83, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_indexonlyscan', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_indexonlyscan', index=82,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_material', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_material', index=83,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_mergejoin', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_mergejoin', index=84,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_nestloop', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_nestloop', index=85,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_seqscan', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_seqscan', index=86,
      number=88, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_sort', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_sort', index=87,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_tidscan', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_tidscan', index=88,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_worker_processes', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_worker_processes', index=89,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_parallel_workers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_parallel_workers', index=90,
      number=92, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_parallel_workers_per_gather', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_parallel_workers_per_gather', index=91,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_vacuum_scale_factor', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_vacuum_scale_factor', index=92,
      number=94, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070.0-1.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_analyze_scale_factor', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_analyze_scale_factor', index=93,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070.0-1.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_transaction_read_only', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.default_transaction_read_only', index=94,
      number=96, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.timezone', index=95,
      number=97, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_parallel_append', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_parallel_append', index=96,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_parallel_hash', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_parallel_hash', index=97,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_partition_pruning', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_partition_pruning', index=98,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_partitionwise_aggregate', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_partitionwise_aggregate', index=99,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_partitionwise_join', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_partitionwise_join', index=100,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.jit', index=101,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_parallel_maintenance_workers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_parallel_maintenance_workers', index=102,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parallel_leader_participation', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.parallel_leader_participation', index=103,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vacuum_cleanup_index_scale_factor', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.vacuum_cleanup_index_scale_factor', index=104,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0210.0-10000000000.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_transaction_sample_rate', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_transaction_sample_rate', index=105,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070.0-1.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_cache_mode', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.plan_cache_mode', index=106,
      number=108, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_io_concurrency', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.effective_io_concurrency', index=107,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_cache_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.effective_cache_size', index=108,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0160-549755813888', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_preload_libraries', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.shared_preload_libraries', index=109,
      number=111, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_min_duration', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_min_duration', index=110,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r-1-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_analyze', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_analyze', index=111,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_buffers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_buffers', index=112,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_timing', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_timing', index=113,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_triggers', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_triggers', index=114,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_verbose', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_verbose', index=115,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_log_nested_statements', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_log_nested_statements', index=116,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_explain_sample_rate', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.auto_explain_sample_rate', index=117,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070.0-1.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_hint_plan_enable_hint', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_hint_plan_enable_hint', index=118,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_hint_plan_enable_hint_table', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_hint_plan_enable_hint_table', index=119,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_hint_plan_debug_print', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_hint_plan_debug_print', index=120,
      number=122, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_hint_plan_message_level', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_hint_plan_message_level', index=121,
      number=123, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_mem_multiplier', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.hash_mem_multiplier', index=122,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\n0.0-1000.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logical_decoding_work_mem', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.logical_decoding_work_mem', index=123,
      number=126, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\02365536-1099511627776', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_io_concurrency', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.maintenance_io_concurrency', index=124,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_slot_wal_keep_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.max_slot_wal_keep_size', index=125,
      number=128, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\023-1-2251799812636672', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wal_keep_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.wal_keep_size', index=126,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\023-1-2251799812636672', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_incremental_sort', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.enable_incremental_sort', index=127,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_vacuum_insert_threshold', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_vacuum_insert_threshold', index=128,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r-1-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autovacuum_vacuum_insert_scale_factor', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.autovacuum_vacuum_insert_scale_factor', index=129,
      number=132, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\t0.0-100.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_min_duration_sample', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_min_duration_sample', index=130,
      number=133, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r-1-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_statement_sample_rate', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_statement_sample_rate', index=131,
      number=134, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070.0-1.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_parameter_max_length', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_parameter_max_length', index=132,
      number=135, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r-1-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_parameter_max_length_on_error', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.log_parameter_max_length_on_error', index=133,
      number=136, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r-1-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_qualstats_enabled', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_qualstats_enabled', index=134,
      number=137, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_qualstats_track_constants', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_qualstats_track_constants', index=135,
      number=138, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_qualstats_max', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_qualstats_max', index=136,
      number=139, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_qualstats_resolve_oids', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_qualstats_resolve_oids', index=137,
      number=140, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pg_qualstats_sample_rate', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.pg_qualstats_sample_rate', index=138,
      number=141, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plantuner_fix_empty_table', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.plantuner_fix_empty_table', index=139,
      number=149, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo', index=140,
      number=152, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo_threshold', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo_threshold', index=141,
      number=153, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0142-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo_effort', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo_effort', index=142,
      number=154, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0041-10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo_pool_size', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo_pool_size', index=143,
      number=155, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo_generations', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo_generations', index=144,
      number=156, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo_selection_bias', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo_selection_bias', index=145,
      number=157, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071.5-2.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geqo_seed', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C.geqo_seed', index=146,
      number=158, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070.0-1.0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POSTGRESQLCONFIG13_1C_BACKSLASHQUOTE,
    _POSTGRESQLCONFIG13_1C_BYTEAOUTPUT,
    _POSTGRESQLCONFIG13_1C_CONSTRAINTEXCLUSION,
    _POSTGRESQLCONFIG13_1C_FORCEPARALLELMODE,
    _POSTGRESQLCONFIG13_1C_LOGERRORVERBOSITY,
    _POSTGRESQLCONFIG13_1C_LOGLEVEL,
    _POSTGRESQLCONFIG13_1C_LOGSTATEMENT,
    _POSTGRESQLCONFIG13_1C_PGHINTPLANDEBUGPRINT,
    _POSTGRESQLCONFIG13_1C_PLANCACHEMODE,
    _POSTGRESQLCONFIG13_1C_SHAREDPRELOADLIBRARIES,
    _POSTGRESQLCONFIG13_1C_SYNCHRONOUSCOMMIT,
    _POSTGRESQLCONFIG13_1C_TRANSACTIONISOLATION,
    _POSTGRESQLCONFIG13_1C_WALLEVEL,
    _POSTGRESQLCONFIG13_1C_XMLBINARY,
    _POSTGRESQLCONFIG13_1C_XMLOPTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=12912,
)


_POSTGRESQLCONFIGSET13_1C = _descriptor.Descriptor(
  name='PostgresqlConfigSet13_1C',
  full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1C',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1C.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1C.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1C.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12915,
  serialized_end=13198,
)

_POSTGRESQLCONFIG13_1C.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['shared_buffers'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['temp_buffers'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_prepared_transactions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['work_mem'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['maintenance_work_mem'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_work_mem'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['temp_file_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cost_delay'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cost_page_hit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cost_page_miss'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cost_page_dirty'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cost_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['bgwriter_delay'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['bgwriter_lru_maxpages'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['bgwriter_lru_multiplier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['bgwriter_flush_after'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['backend_flush_after'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['old_snapshot_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['wal_level'].enum_type = _POSTGRESQLCONFIG13_1C_WALLEVEL
_POSTGRESQLCONFIG13_1C.fields_by_name['synchronous_commit'].enum_type = _POSTGRESQLCONFIG13_1C_SYNCHRONOUSCOMMIT
_POSTGRESQLCONFIG13_1C.fields_by_name['checkpoint_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['checkpoint_completion_target'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['checkpoint_flush_after'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_wal_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['min_wal_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_standby_streaming_delay'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['default_statistics_target'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['constraint_exclusion'].enum_type = _POSTGRESQLCONFIG13_1C_CONSTRAINTEXCLUSION
_POSTGRESQLCONFIG13_1C.fields_by_name['cursor_tuple_fraction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['from_collapse_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['join_collapse_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['force_parallel_mode'].enum_type = _POSTGRESQLCONFIG13_1C_FORCEPARALLELMODE
_POSTGRESQLCONFIG13_1C.fields_by_name['client_min_messages'].enum_type = _POSTGRESQLCONFIG13_1C_LOGLEVEL
_POSTGRESQLCONFIG13_1C.fields_by_name['log_min_messages'].enum_type = _POSTGRESQLCONFIG13_1C_LOGLEVEL
_POSTGRESQLCONFIG13_1C.fields_by_name['log_min_error_statement'].enum_type = _POSTGRESQLCONFIG13_1C_LOGLEVEL
_POSTGRESQLCONFIG13_1C.fields_by_name['log_min_duration_statement'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_checkpoints'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_disconnections'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_error_verbosity'].enum_type = _POSTGRESQLCONFIG13_1C_LOGERRORVERBOSITY
_POSTGRESQLCONFIG13_1C.fields_by_name['log_lock_waits'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_statement'].enum_type = _POSTGRESQLCONFIG13_1C_LOGSTATEMENT
_POSTGRESQLCONFIG13_1C.fields_by_name['log_temp_files'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['row_security'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['default_transaction_isolation'].enum_type = _POSTGRESQLCONFIG13_1C_TRANSACTIONISOLATION
_POSTGRESQLCONFIG13_1C.fields_by_name['statement_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['lock_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['idle_in_transaction_session_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['bytea_output'].enum_type = _POSTGRESQLCONFIG13_1C_BYTEAOUTPUT
_POSTGRESQLCONFIG13_1C.fields_by_name['xmlbinary'].enum_type = _POSTGRESQLCONFIG13_1C_XMLBINARY
_POSTGRESQLCONFIG13_1C.fields_by_name['xmloption'].enum_type = _POSTGRESQLCONFIG13_1C_XMLOPTION
_POSTGRESQLCONFIG13_1C.fields_by_name['gin_pending_list_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['deadlock_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_locks_per_transaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_pred_locks_per_transaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['array_nulls'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['backslash_quote'].enum_type = _POSTGRESQLCONFIG13_1C_BACKSLASHQUOTE
_POSTGRESQLCONFIG13_1C.fields_by_name['default_with_oids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['escape_string_warning'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['lo_compat_privileges'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['operator_precedence_warning'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['quote_all_identifiers'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['standard_conforming_strings'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['synchronize_seqscans'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['transform_null_equals'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['exit_on_error'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['seq_page_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['random_page_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_max_workers'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_cost_delay'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_cost_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_naptime'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['archive_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['track_activity_query_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['online_analyze_enable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_bitmapscan'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_hashagg'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_hashjoin'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_indexscan'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_indexonlyscan'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_material'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_mergejoin'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_nestloop'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_seqscan'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_sort'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_tidscan'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_worker_processes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_parallel_workers'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_parallel_workers_per_gather'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_scale_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_analyze_scale_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['default_transaction_read_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_parallel_append'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_parallel_hash'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_partition_pruning'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_partitionwise_aggregate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_partitionwise_join'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['jit'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_parallel_maintenance_workers'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['parallel_leader_participation'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cleanup_index_scale_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_transaction_sample_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['plan_cache_mode'].enum_type = _POSTGRESQLCONFIG13_1C_PLANCACHEMODE
_POSTGRESQLCONFIG13_1C.fields_by_name['effective_io_concurrency'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['effective_cache_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['shared_preload_libraries'].enum_type = _POSTGRESQLCONFIG13_1C_SHAREDPRELOADLIBRARIES
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_min_duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_analyze'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_buffers'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_timing'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_triggers'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_verbose'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_nested_statements'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_sample_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_hint_plan_enable_hint'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_hint_plan_enable_hint_table'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_hint_plan_debug_print'].enum_type = _POSTGRESQLCONFIG13_1C_PGHINTPLANDEBUGPRINT
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_hint_plan_message_level'].enum_type = _POSTGRESQLCONFIG13_1C_LOGLEVEL
_POSTGRESQLCONFIG13_1C.fields_by_name['hash_mem_multiplier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['logical_decoding_work_mem'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['maintenance_io_concurrency'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['max_slot_wal_keep_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['wal_keep_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['enable_incremental_sort'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_insert_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_insert_scale_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_min_duration_sample'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_statement_sample_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_parameter_max_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['log_parameter_max_length_on_error'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_qualstats_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_qualstats_track_constants'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_qualstats_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_qualstats_resolve_oids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['pg_qualstats_sample_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['plantuner_fix_empty_table'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_effort'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_pool_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_generations'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_selection_bias'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_seed'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_POSTGRESQLCONFIG13_1C_BACKSLASHQUOTE.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_BYTEAOUTPUT.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_CONSTRAINTEXCLUSION.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_FORCEPARALLELMODE.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_LOGERRORVERBOSITY.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_LOGLEVEL.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_LOGSTATEMENT.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_PGHINTPLANDEBUGPRINT.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_PLANCACHEMODE.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_SHAREDPRELOADLIBRARIES.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_SYNCHRONOUSCOMMIT.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_TRANSACTIONISOLATION.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_WALLEVEL.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_XMLBINARY.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIG13_1C_XMLOPTION.containing_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIGSET13_1C.fields_by_name['effective_config'].message_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIGSET13_1C.fields_by_name['user_config'].message_type = _POSTGRESQLCONFIG13_1C
_POSTGRESQLCONFIGSET13_1C.fields_by_name['default_config'].message_type = _POSTGRESQLCONFIG13_1C
DESCRIPTOR.message_types_by_name['PostgresqlConfig13_1C'] = _POSTGRESQLCONFIG13_1C
DESCRIPTOR.message_types_by_name['PostgresqlConfigSet13_1C'] = _POSTGRESQLCONFIGSET13_1C
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PostgresqlConfig13_1C = _reflection.GeneratedProtocolMessageType('PostgresqlConfig13_1C', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRESQLCONFIG13_1C,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.config.postgresql13_1c_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1C)
  })
_sym_db.RegisterMessage(PostgresqlConfig13_1C)

PostgresqlConfigSet13_1C = _reflection.GeneratedProtocolMessageType('PostgresqlConfigSet13_1C', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRESQLCONFIGSET13_1C,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.config.postgresql13_1c_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1C)
  })
_sym_db.RegisterMessage(PostgresqlConfigSet13_1C)


DESCRIPTOR._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['bgwriter_delay']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['bgwriter_flush_after']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['backend_flush_after']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['old_snapshot_threshold']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['checkpoint_timeout']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['checkpoint_flush_after']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['from_collapse_limit']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['join_collapse_limit']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_max_workers']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_cost_delay']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_cost_limit']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_naptime']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['archive_timeout']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['track_activity_query_size']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['max_worker_processes']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['max_parallel_workers']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['max_parallel_workers_per_gather']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_scale_factor']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_analyze_scale_factor']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['max_parallel_maintenance_workers']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['vacuum_cleanup_index_scale_factor']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['log_transaction_sample_rate']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['effective_io_concurrency']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['effective_cache_size']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_log_min_duration']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['auto_explain_sample_rate']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['hash_mem_multiplier']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['logical_decoding_work_mem']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['maintenance_io_concurrency']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['max_slot_wal_keep_size']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['wal_keep_size']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_insert_threshold']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['autovacuum_vacuum_insert_scale_factor']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['log_min_duration_sample']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['log_statement_sample_rate']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['log_parameter_max_length']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['log_parameter_max_length_on_error']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_threshold']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_effort']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_selection_bias']._options = None
_POSTGRESQLCONFIG13_1C.fields_by_name['geqo_seed']._options = None
# @@protoc_insertion_point(module_scope)
